# UI/UX Feedback

**ID:** Feedback-20260221-175407
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-21 17:56:36

## Selected Elements

- `{'selector': 'div.deliverable-card:nth-of-type(2)', 'parents': ['div.workflow-panel.expanded', 'div.workflow-panel-body', 'div.deliverables-area', 'div.deliverables-grid']}`

## Feedback

it's not aligned with other deliverables, and looks like I cannot click on any deliverable to see the data. is it because it's in the features which not implemented? if that's the case list which features they are, if not fix it

## Screenshot

![Screenshot](./page-screenshot.png)
